@@ -1,3 +1,5 @@
+from pyramid.compat import escape
+
 from pyramid.httpexceptions import HTTPFound
 from pyramid.response import Response
 from pyramid.view import view_config
@@ -14,7 +16,8 @@ def home_view(request):
 def hello_view(request):
     name = request.params.get('name', 'No Name')
     body = '<p>Hi %s, this <a href="/goto">redirects</a></p>'
-    return Response(body % name)
+    # pyramid.compat.escape to prevent Cross-Site Scripting (XSS) [CWE 79]
+    return Response(body % escape(name))
 
 
 # /goto which issues HTTP redirect to the last view
@@ -23,7 +26,7 @@ def redirect_view(request):
     return HTTPFound(location="/problem")
 
 
-# /problem which causes an site error
+# /problem which causes a site error
 @view_config(route_name='exception')
 def exception_view(request):
     raise Exception()
